@@ -41,7 +41,7 @@ TOOLS={
   "dlstreamer-services":['dlstreamer-framework','dlstreamer-pipeline-zoo','dlstreamer-pipline-composer','dlstreamer-server','edge-ai-extension'],
   "edge-deployment-services":['cfa','edge-conductor','edge-software-configurator','pace'],
   "edge-inference-services":['artifactory','dev-catalog','kube-apps','mrs','rrk'],
-  "edge-to-cloud-services":['aws-solutions','azure-solutions','dev-catalog','market-ready-solutions','redhat-marketplace','select-solutions','seo'],
+  "edge-to-cloud-services":['aws-solutions','azure-solutions','dev-catalog','market-ready-solutions','redhat-marketplace','select-solutions','seo-reference-implementations'],
   "k8s-tools":['kind','kubeadm','microk8s','minikube','openshift','rancher','smart-edge-open','tanzu'],
 
 }
